@@ -89,6 +89,7 @@ CURTSIES_NAMES = dict([
 
   (b"\x1b[2~", u'<INSERT>'),       # insert (0)
   (b"\x1b[3~", u'<DELETE>'),       # delete (.), "Execute"
+  (b"\x1b[3;5~", u'<Ctrl-DELETE>'),
 
   # not fixing for back compat.
   # (b"\x1b[4~", u'<SELECT>'),       # select
@@ -104,4 +105,11 @@ CURTSIES_NAMES = dict([
   (b"\x1b[OF", u'<END>'),          # end    (1)
   (b"\x1b[OH", u'<HOME>'),         # home   (7)
 
-  ])
+  # reported by cool-RR
+  (b"\x1b[[A", u'<F1>'),
+  (b"\x1b[[B", u'<F2>'),
+  (b"\x1b[[C", u'<F3>'),
+  (b"\x1b[[D", u'<F4>'),
+  (b"\x1b[[E", u'<F5>'),
+  # cool-RR says the rest were good, see issue #99
+])
