@@ -93,8 +93,10 @@ class Chunk(object):
         s = self.s
         for k, v in sorted(self.atts.items()):
             # (self.atts sorted for the sake of always acting the same.)
-            assert k in xforms, "XXX Do we actually get cases like this?"
-            if v is False:
+            if k not in xforms:
+                # Unsupported SGR code
+                continue
+            elif v is False:
                 continue
             elif v is True:
                 s = xforms[k](s)
@@ -290,6 +292,13 @@ class FmtStr(object):
             [0] + [m.end() for m in matches],
             [m.start() for m in matches] + [len(s)])]
 
+    def splitlines(self, keepends=False):
+        """Return a list of lines, split on newline characters,
+        include line boundaries, if keepends is true."""
+        lines = self.split('\n')
+        return [line+'\n' for line in lines] if keepends else (
+               lines if lines[-1] else lines[:-1])
+
     # proxying to the string via __getattr__ is insufficient
     # because we shouldn't drop foreground or formatting info
     def ljust(self, width, fillchar=None):
@@ -514,7 +523,9 @@ def interval_overlap(a, b, x, y):
 
 
 def width_aware_slice(s, start, end, replacement_char=u' '):
-    divides = [wcwidth.wcswidth(s, i) for i in range(len(s)+1)]
+    divides = [0]
+    for c in s:
+        divides.append(divides[-1] + wcwidth.wcswidth(c))
 
     new_chunk_chars = []
     for char, char_start, char_end in zip(s, divides[:-1], divides[1:]):
